==> common_api-2.7.0.1-sources.jar: com/cloud/sdk/commonutil/control/AdxPreferencesHelper.java <==
package com.cloud.sdk.commonutil.control;


import android.util.Log;

import com.cloud.sdk.commonutil.util.CommonLogUtil;
import com.cloud.sdk.commonutil.util.WorkThread;
import com.transsion.core.utils.SharedPreferencesUtil;

import java.util.HashSet;
import java.util.Set;

/**
 * Created by peng.sun on 2017/6/29.
 */

public class AdxPreferencesHelper {
    private static final String TAG = "AdxPreferencesHelper";
    /**
     * 需要操作的文件名，广告的SDk默认名称
     */
    private static final String SP_NAME = "hisavana_sdk";
    private static final AdxPreferencesHelper INSTANCE = new AdxPreferencesHelper();
    private HisavanaMMKV hisavanaMMKV;

    private AdxPreferencesHelper() {
        try {
            Class<?> c = Class.forName("com.tencent.mmkv.MMKV");
            if (c == null) {
                CommonLogUtil.Log().e(TAG,"mmkv is not implementation");
                return;
            }
            hisavanaMMKV = HisavanaMMKV.getInstance();
        } catch (Exception e) {
            CommonLogUtil.Log().e(TAG,"init mmkv error "+ Log.getStackTraceString(e));
        }
    }

    /**
     * 获得AdxPreferencesHelper实例
     *
     * @return
     */
    public static AdxPreferencesHelper getInstance() {
        return INSTANCE;
    }

    public void clear() {
        if (hisavanaMMKV != null) {
            hisavanaMMKV.clear();
        } else {
            SharedPreferencesUtil.getInstance(SP_NAME).clear();
        }
    }
    public void putString(String key, String value) {
        if (hisavanaMMKV == null) {
            SharedPreferencesUtil.getInstance(SP_NAME).putString(key, value);
        } else {
            hisavanaMMKV.putString(key, value);
        }
    }

    public String getString(String key, String defaultValue) {
        if (hisavanaMMKV != null) {
            return hisavanaMMKV.getString(key, defaultValue);
        } else {
            return SharedPreferencesUtil.getInstance(SP_NAME).getString(key, defaultValue);
        }
    }

    public String getString(String key) {
        return getString(key, "");
    }

    public void putInt(String key, int value) {
        if (hisavanaMMKV != null) {
            hisavanaMMKV.putInt(key, value);
        } else {
            SharedPreferencesUtil.getInstance(SP_NAME).putInt(key, value);
        }
    }

    public int getInt(String key, int defaultValue) {
        if (hisavanaMMKV != null) {
            return hisavanaMMKV.getInt(key, defaultValue);
        } else {
            return SharedPreferencesUtil.getInstance(SP_NAME).getInt(key, defaultValue);
        }
    }

    public int getInt(String key) {
        return getInt(key, 0);
    }

    public void putBoolean(String key, boolean value) {
        if (hisavanaMMKV != null) {
            hisavanaMMKV.putBoolean(key, value);
        } else {
            SharedPreferencesUtil.getInstance(SP_NAME).putBoolean(key, value);
        }
    }

    public boolean getBoolean(String key, boolean defaultValue) {
        if (hisavanaMMKV != null) {
            return hisavanaMMKV.getBoolean(key, defaultValue);
        } else {
            return SharedPreferencesUtil.getInstance(SP_NAME).getBoolean(key, defaultValue);
        }
    }

    public boolean getBoolean(String key) {
        return getBoolean(key, false);
    }

    public void putLong(String key, long value) {
        if (hisavanaMMKV != null) {
            hisavanaMMKV.putLong(key, value);
        } else {
            SharedPreferencesUtil.getInstance(SP_NAME).putLong(key, value);
        }
    }

    public long getLong(String key, long defaultValue) {
        if (hisavanaMMKV != null) {
            return hisavanaMMKV.getLong(key, defaultValue);
        } else {
            return SharedPreferencesUtil.getInstance(SP_NAME).getLong(key, defaultValue);
        }
    }

    public long getLong(String key) {
        return getLong(key, 0);
    }

    public Set<String> getStringSet(String key, Set<String> defaultValue) {
        if (hisavanaMMKV != null) {
            return hisavanaMMKV.getStringSet(key, defaultValue);
        } else {
            return SharedPreferencesUtil.getInstance(SP_NAME).getStringSet(key, defaultValue);
        }
    }

    public Set<String> getStringSet(String key) {
        return getStringSet(key, new HashSet<>());
    }
}

==> common_api-2.9.3.0-sources.jar: com/cloud/sdk/commonutil/control/AdxPreferencesHelper.java <==
package com.cloud.sdk.commonutil.control;


import android.text.TextUtils;
import android.util.Log;

import com.cloud.sdk.commonutil.util.CommonLogUtil;
import com.cloud.sdk.commonutil.util.WorkThread;
import com.transsion.core.utils.SharedPreferencesUtil;

import java.util.HashSet;
import java.util.Set;

/**
 * Created by peng.sun on 2017/6/29.
 */

public class AdxPreferencesHelper {
    private static final String TAG = "AdxPreferencesHelper";
    /**
     * 需要操作的文件名，广告的SDk默认名称
     */
    private static final String SP_NAME = "hisavana_sdk";
    private static final AdxPreferencesHelper INSTANCE = new AdxPreferencesHelper();
    private HisavanaMMKV hisavanaMMKV;

    private AdxPreferencesHelper() {
        try {
            Class<?> c = Class.forName("com.tencent.mmkv.MMKV");
            if (c == null) {
                CommonLogUtil.Log().e(TAG,"mmkv is not implementation");
                return;
            }
            hisavanaMMKV = HisavanaMMKV.getInstance();
        } catch (Exception e) {
            CommonLogUtil.Log().e(TAG,"init mmkv error "+ Log.getStackTraceString(e));
        }
    }

    /**
     * 获得AdxPreferencesHelper实例
     *
     * @return
     */
    public static AdxPreferencesHelper getInstance() {
        return INSTANCE;
    }

    public void clear() {
        if (hisavanaMMKV != null) {
            hisavanaMMKV.clear();
        } else {
            SharedPreferencesUtil.getInstance(SP_NAME).clear();
        }
    }
    public void putString(String key, String value) {
        if (hisavanaMMKV == null) {
            SharedPreferencesUtil.getInstance(SP_NAME).putString(key, value);
        } else {
            hisavanaMMKV.putString(key, value);
        }
    }

    public String getString(String key, String defaultValue) {
        if (hisavanaMMKV != null) {
            return hisavanaMMKV.getString(key, defaultValue);
        } else {
            return SharedPreferencesUtil.getInstance(SP_NAME).getString(key, defaultValue);
        }
    }

    public String getString(String key) {
        return getString(key, "");
    }

    public void putInt(String key, int value) {
        if (hisavanaMMKV != null) {
            hisavanaMMKV.putInt(key, value);
        } else {
            SharedPreferencesUtil.getInstance(SP_NAME).putInt(key, value);
        }
    }

    public int getInt(String key, int defaultValue) {
        if (hisavanaMMKV != null) {
            return hisavanaMMKV.getInt(key, defaultValue);
        } else {
            return SharedPreferencesUtil.getInstance(SP_NAME).getInt(key, defaultValue);
        }
    }

    public int getInt(String key) {
        return getInt(key, 0);
    }

    public void putBoolean(String key, boolean value) {
        if (hisavanaMMKV != null) {
            hisavanaMMKV.putBoolean(key, value);
        } else {
            SharedPreferencesUtil.getInstance(SP_NAME).putBoolean(key, value);
        }
    }

    public boolean getBoolean(String key, boolean defaultValue) {
        if (hisavanaMMKV != null) {
            return hisavanaMMKV.getBoolean(key, defaultValue);
        } else {
            return SharedPreferencesUtil.getInstance(SP_NAME).getBoolean(key, defaultValue);
        }
    }

    public boolean getBoolean(String key) {
        return getBoolean(key, false);
    }

    public void putLong(String key, long value) {
        if (hisavanaMMKV != null) {
            hisavanaMMKV.putLong(key, value);
        } else {
            SharedPreferencesUtil.getInstance(SP_NAME).putLong(key, value);
        }
    }

    public long getLong(String key, long defaultValue) {
        if (hisavanaMMKV != null) {
            return hisavanaMMKV.getLong(key, defaultValue);
        } else {
            return SharedPreferencesUtil.getInstance(SP_NAME).getLong(key, defaultValue);
        }
    }

    public long getLong(String key) {
        return getLong(key, 0);
    }

    public Set<String> getStringSet(String key, Set<String> defaultValue) {
        if (hisavanaMMKV != null) {
            return hisavanaMMKV.getStringSet(key, defaultValue);
        } else {
            return SharedPreferencesUtil.getInstance(SP_NAME).getStringSet(key, defaultValue);
        }
    }

    public Set<String> getStringSet(String key) {
        return getStringSet(key, new HashSet<>());
    }

    /**
     * 根据key来删除对应的值
     * @param key
     */
    public void remove(String key) {
        if(TextUtils.isEmpty(key)){
            return;
        }
        if (hisavanaMMKV != null) {
            hisavanaMMKV.remove(key);
        } else {
            SharedPreferencesUtil.getInstance(SP_NAME).remove(key);
        }
    }
}
